Welcome to Dos’s documentation! — HAX712X-DOS 1.0.0 documentation

# Welcome to Dos’s documentation!

This package was made as a project in the software devlopment course. The main goal here is to predict the three sources of energier (electric consumption, Gaz and Nuclear) at France country-wise scale. And also providing an interactive map of France at the city-wise level displaying the yearly average household electricity consumption between 2018 and 2021. And because we mainly learn with examples, detailled explanations of the objects and their construction are presented in the gallery.

## Guide

Predection, Data Collection

- Project.Prediction Module
- Project.Prediction.DataCollection module

interactive card

- Project.Map.ChoroFraBy module
- Project.Map.ConsumptionBy module

Examples

- Examples of ClassModel
  - The Impodtation of the Package:
  - Load the data
- Examples of maps
  - The extracts from the tables produced by ConsumptionBy:
  - Choropleth Map

# Indices and tables

- Index

- Module Index

- Search Page